///File : DialogMdoEdit.hpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#if not defined DIALOG_MDO_EDIT_HPP_DEVIS_MAKER
#define DIALOG_MDO_EDIT_HPP_DEVIS_MAKER

//------------------------------------------------------------------------------
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif
//------------------------------------------------------------------------------
#include <ConfigManager.hpp>
//------------------------------------------------------------------------------
#include "config.hpp"
#include "buildVersionOptions.hpp"
//------------------------------------------------------------------------------
#include <wx/listctrl.h>
#include <wx/event.h>
#include <wx/wupdlock.h>
#include <wx/treectrl.h>
#include <wx/imaglist.h>
//------------------------------------------------------------------------------
#include "findFile.hpp"
#include "strWxStdConv.hpp"
#include "mdo.hpp"

//------------------------------------------------------------------------------
//-                               DialogMdoEdit                                   -
//------------------------------------------------------------------------------
class DialogMdoEdit : public wxDialog
{
public:
    DialogMdoEdit(wxWindow* parent, wxWindowID id, ConfigManager *generalCfg, const std::string &mainMdoSizerName, const wxString &title = _("Edit the Invoice's / Estimate's presentation"), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize(800, 600), long style = wxCAPTION | wxCLOSE_BOX | wxSYSTEM_MENU | wxRESIZE_BORDER | wxMAXIMIZE_BOX | wxMINIMIZE_BOX);
    ~DialogMdoEdit();

    // Events
    void OnPaint(wxPaintEvent& event);

        // Tree
    void OnTreeEndLabelEdit(wxTreeEvent& event);
    void OnTreeBeginLabelEdit(wxTreeEvent& event);
    void OnTreeBeginDrag(wxTreeEvent& event);
    void OnTreeEndDrag(wxTreeEvent& event);
    void OnTreeSelect(wxTreeEvent& event);
    void OnTreeItemMenu(wxTreeEvent& event);
    void OnTreeItemActivated(wxTreeEvent& event);
    void OnTreeKeyDown(wxTreeEvent& event);

        // Bts / Menu
    void OnAdd(wxEvent& event);
    void OnRemove(wxEvent& event);
    void OnRename(wxEvent& event);
    void OnEdit(wxEvent& event);

    void OnUp(wxEvent& event);
    void OnDown(wxEvent& event);
    void OnCopy(wxEvent& event);
    void OnCut(wxEvent& event);
    void OnPast(wxEvent& event);

    #if defined(__WXMSW__)
    void OnResize(wxSizeEvent &event);
    #endif

    // Tree
    void BuildTree();
    void AddSizerToTree(const wxTreeItemId &item, mdo::Sizer *sizer);
    void MoveCopyMdo(mdo::DrawableObject *srcMdo, mdo::DrawableObject *destMdo, const bool &copy = false, const bool &addInIfsizer = true, const bool &addAfterDest = true);

    // Autre
    //std::string GetUniqueMdoName(const std::string &prefix, const std::string &type);

    // Refresh
    void RefreshBts();
    void ForceRefreshDrawRect();

protected:
    int GetTreeImagePos(const mdo::DrawableObject *mdo);
    bool VerifName(const wxString &name) const;

    // Bts
    wxButton *m_btAdd, *m_btRemove, *m_btRename, *m_btEdit;
    wxMenuItem *m_itemAdd, *m_itemRemove, *m_itemRename, *m_itemEdit, *m_ItemUp, *m_ItemDown, *m_ItemCopy, *m_ItemCut, *m_ItemPast;
    wxMenu m_PopupMenu;

    // Portrait
    bool m_isPortrait;
    wxStaticText *m_labelMode;

    // Cfg
    ConfigManager *m_generalCfg;

    wxSizer *m_drawSpaceSizer;
    wxRect m_currentDrawRect;

    // Tree
    wxTreeCtrl *m_tree;

    // Cp, cut & DnD
    mdo::DrawableObject *m_draggedMdo;

    mdo::DrawableObject *m_copyCutMdo;
    bool m_isCopy;

    // Mdo
    mdo::Sizer *m_mainMdoSizer;

    std::vector<std::string> m_mdoTypeNameList;
};
//------------------------------------------------------------------------------

#endif //#if defined USE_BAR_CODE_MODE
